===========================================================
scTM: A pacakge for topic modelling in transcriptomics data 
===========================================================

.. image:: https://img.shields.io/pypi/v/sctm.svg
        :target: https://pypi.python.org/pypi/sctm


.. image:: https://readthedocs.org/projects/sctm/badge/?version=latest
        :target: https://JinmiaoChenLab.github.io/scTM/
        :alt: Documentation Status



scTM is a package for spatial transcriptomics for single cell that uses topic modelling, solved with stochastic variational infernce. The intresting
part is with the formulation of topic models, we can get interpretable embedding which are useful for downstream analysis.

Currently available modules: STAMP

* Free software: MIT license
* Documentation: https://JinmiaoChenLab.github.io/scTM/.


Features
--------

- STAMP: A spatially-aware dimensional reduction designed for spatial data.

Minimal Installation
--------------------

``
pip install scTM
``

or

``
conda create --name sctm python=3.8
git clone https://JinmiaoChenLab.github.io/scTM/
cd scTM
pip install .
``

Basic Usage
-----------
To be added


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
